X-Git-Url: http://cvs.zerfleddert.de/cgi-bin/gitweb.cgi/proxmark3-svn/blobdiff_plain/6c283951062aaad9d0d1ba8670b02895047be438..81e82dfe51a5db10d780ffcdb4fd913a4a9c310b:/client/cmdlfnedap.c

diff --git a/client/cmdlfnedap.c b/client/cmdlfnedap.c
index 9e6a624b..21d47fb9 100644
--- a/client/cmdlfnedap.c
+++ b/client/cmdlfnedap.c
@@ -14,12 +14,13 @@ static int CmdHelp(const char *Cmd);
 int usage_lf_nedap_clone(void){
 	PrintAndLog("clone a NEDAP tag to a T55x7 tag.");
 	PrintAndLog("");
-	PrintAndLog("Usage: lf nedap clone <Card-Number>");
-	PrintAndLog("Options :");
-	PrintAndLog("  <Card Number>   : 24-bit value card number");
-//	PrintAndLog("  Q5              : optional - clone to Q5 (T5555) instead of T55x7 chip");
+	PrintAndLog("Usage: lf nedap clone [h] <Card-Number>");
+	PrintAndLog("Options:");
+	PrintAndLog("      h             : This help");
+	PrintAndLog("      <Card Number> : 24-bit value card number");
+//	PrintAndLog("      Q5            : optional - clone to Q5 (T5555) instead of T55x7 chip");
 	PrintAndLog("");
-	PrintAndLog("Sample  : lf nedap clone 112233");
+	PrintAndLog("Sample: lf nedap clone 112233");
 	return 0;
 }
 
@@ -27,11 +28,12 @@ int usage_lf_nedap_sim(void) {
 	PrintAndLog("Enables simulation of NEDAP card with specified card number.");
 	PrintAndLog("Simulation runs until the button is pressed or another USB command is issued.");
 	PrintAndLog("");
-	PrintAndLog("Usage:  lf nedap sim <Card-Number>");
-	PrintAndLog("Options :");
-	PrintAndLog("  <Card Number>   : 24-bit value card number");
+	PrintAndLog("Usage:  lf nedap sim [h] <Card-Number>");
+	PrintAndLog("Options:");
+	PrintAndLog("      h               : This help");
+	PrintAndLog("      <Card Number>   : 24-bit value card number");
 	PrintAndLog("");
-	PrintAndLog("Sample  : lf nedap sim 112233");
+	PrintAndLog("Sample: lf nedap sim 112233");
 	return 0;
 }
 
@@ -83,7 +85,7 @@ int GetNedapBits(uint32_t cn, uint8_t *nedapBits) {
 int CmdLFNedapDemod(const char *Cmd) {
 	//raw ask demod no start bit finding just get binary from wave
 	if (!ASKbiphaseDemod("0 64 0 0", FALSE)) {
-		if (g_debugMode) PrintAndLog("Error NEDAP: ASKbiphaseDemod failed");
+		if (g_debugMode) PrintAndLog("DEBUG: Error - Nedap ASKbiphaseDemod failed");
 		return 0;
 	}
 	size_t size = DemodBufferLen;
@@ -97,11 +99,11 @@ int CmdLFNedapDemod(const char *Cmd) {
 			// else if (idx == -2)
 				// PrintAndLog("DEBUG: Error - problem during ASK/Biphase demod");
 			if (idx == -3)
-				PrintAndLog("DEBUG: Error - Size not correct: %d", size);
+				PrintAndLog("DEBUG: Error - Nedap Size not correct: %d", size);
 			else if (idx == -4)
-				PrintAndLog("DEBUG: Error - NEDAP preamble not found");
+				PrintAndLog("DEBUG: Error - Nedap preamble not found");
 			else
-				PrintAndLog("DEBUG: Error - idx: %d",idx);
+				PrintAndLog("DEBUG: Error - Nedap idx: %d",idx);
 		}
 		return 0;
 	}
@@ -137,13 +139,13 @@ int CmdLFNedapDemod(const char *Cmd) {
 
 	uint8_t firstParity = GetParity( DemodBuffer, EVEN, 63);
 	if ( firstParity != DemodBuffer[63]  ) {
-		PrintAndLog("1st 64bit parity check failed:  %d|%d ", DemodBuffer[63], firstParity);
+		PrintAndLog("DEBUG: Error - Nedap 1st 64bit parity check failed:  %d|%d ", DemodBuffer[63], firstParity);
 		return 0;
 	}
 
 	uint8_t secondParity = GetParity( DemodBuffer+64, EVEN, 63);
 	if ( secondParity != DemodBuffer[127]  ) {
-		PrintAndLog("2st 64bit parity check failed:  %d|%d ", DemodBuffer[127], secondParity);
+		PrintAndLog("DEBUG: Error - Nedap 2st 64bit parity check failed:  %d|%d ", DemodBuffer[127], secondParity);
 		return 0;
 	}
 
@@ -200,7 +202,7 @@ lf t55xx wr b 4 d 4c0003ff
 
 int CmdLFNedapRead(const char *Cmd) {
 	CmdLFRead("s");
-	getSamples("30000",false);
+	getSamples("20000", TRUE);
 	return CmdLFNedapDemod("");
 }
 /*
@@ -224,13 +226,14 @@ int CmdLFNedapClone(const char *Cmd) {
 		return 1;
 	}	
 
-	((ASK/biphase   data rawdemod ab 0 64 1 0
-	//NEDAP - compat mode, ASK/Biphase, data rate 64, 4 data blocks
-	blocks[0] = T55x7_MODULATION_BIPHASE | T55x7_BITRATE_RF_64 | 4<<T55x7_MAXBLOCK_SHIFT;
+	((ASK/DIphase   data rawdemod ab 0 64 1 0
+	//NEDAP - compat mode, ASK/DIphase, data rate 64, 4 data blocks
+	// DI-pahse (CDP) T55x7_MODULATION_DIPHASE
+	blocks[0] = T55x7_MODULATION_DIPHASE | T55x7_BITRATE_RF_64 | 7<<T55x7_MAXBLOCK_SHIFT;
 
 	if (param_getchar(Cmd, 3) == 'Q' || param_getchar(Cmd, 3) == 'q')
 		//t5555 (Q5) BITRATE = (RF-2)/2 (iceman)
-		blocks[0] = T5555_MODULATION_BIPHASE | T5555_INVERT_OUTPUT | 64<<T5555_BITRATE_SHIFT | 4<<T5555_MAXBLOCK_SHIFT;
+		blocks[0] = T5555_MODULATION_BIPHASE | T5555_INVERT_OUTPUT | 64<<T5555_BITRATE_SHIFT | 7<<T5555_MAXBLOCK_SHIFT;
 
 	blocks[1] = bytebits_to_byte(bs,32);
 	blocks[2] = bytebits_to_byte(bs+32,32);
@@ -251,7 +254,7 @@ int CmdLFNedapClone(const char *Cmd) {
 		c.arg[1] = i;
 		clearCommandBuffer();
 		SendCommand(&c);
-		if (!WaitForResponseTimeout(CMD_ACK, &resp, 1000)){
+		if (!WaitForResponseTimeout(CMD_ACK, &resp, T55XX_WRITE_TIMEOUT)){
 			PrintAndLog("Error occurred, device did not respond during write operation.");
 			return -1;
 		}
@@ -271,13 +274,13 @@ int CmdLFNedapSim(const char *Cmd) {
 	size_t size = sizeof(bs);
 	memset(bs, 0x00, size);
 	
 	// NEDAP,  Bihase = 2, clock 64, inverted, 
 	uint8_t encoding = 2, separator = 0, clk=64, invert=1;
 	uint16_t arg1, arg2;
 	arg1 = clk << 8 | encoding;
 	arg2 = invert << 8 | separator;
 
-	if (sscanf(Cmd, "%u", &cn ) != 2) return usage_lf_nedap_sim();
+	if (sscanf(Cmd, "%u", &cn ) != 1) return usage_lf_nedap_sim();
 	cardnumber = (cn & 0x00FFFFFF);
 	
 	if ( !GetNedapBits(cardnumber, bs)) {
@@ -294,10 +297,8 @@ int CmdLFNedapSim(const char *Cmd) {
 	return 0;
 }
 
-
-
 int CmdLFNedapChk(const char *Cmd){
-    
+    //301600714021BE
 	uint8_t data[256] = { 0x30, 0x16, 0x00, 0x71, 0x40, 0x21, 0xBE};
 	int len = 0;
 	param_gethex_ex(Cmd, 0, data, &len);
@@ -312,7 +313,7 @@ int CmdLFNedapChk(const char *Cmd){
     uint8_t cl = 0x1D, ch = 0x1D, carry = 0;
     uint8_t al, bl, temp;
     
-	for (int i = 0; i < len; ++i){
+	for (int i =len; i >= 0; --i){
 		al = data[i];
         for (int j = 8; j > 0; --j) {
 			
@@ -339,7 +340,7 @@ int CmdLFNedapChk(const char *Cmd){
         }
     }
 	
-	PrintAndLog("Nedap checksum: [ 0x21, 0xBE ] %x", ((ch << 8) | cl) );
+	PrintAndLog("Nedap checksum: 0x%X", ((ch << 8) | cl) );
 	return 0;
 }
@@ -271,13 +274,13 @@ int CmdLFNedapSim(const char *Cmd) {
 	memset(bs, 0x00, size);
 	
-	// NEDAP,  Bihase = 2, clock 64, inverted, 
+	// NEDAP,  Biphase = 2, clock 64, inverted,  (DIPhase == inverted BIphase
 	uint8_t encoding = 2, separator = 0, clk=64, invert=1;
 	uint16_t arg1, arg2;